********************************************************************************
********************************************************************************
****
**** Replication file 3 for:
****   Gerber, Alan S., Gregory A. Huber, Daniel R. Biggers, and David J.
****     Hendry. "Why Don't People Vote in U.S. Primary Elections? Assessing
****     Theoretical Explanations for Reduced Participation." Electoral Studies.
****
****   This file uses the final dataset generated in "02_RecodeVariables.do"
****   and performs the analysis in the paper. 
****
********************************************************************************
********************************************************************************

log using Logs/03_PerformAnalysis.txt, text replace

clear
set more off

** users should maintain the given directory structure and set the working
**   directory to be the location of this .do file
*cd ...

** read in data
use Data/PrimarySurveyWithContextVariables-Recodes.dta, clear

********************************************************************************
**** Part 1: Simple Calculus of Voting
********************************************************************************

** direct costs of getting to the polls for primary elections, reported in
**   footnote 3
tab yhp29b [aweight = weight]
tab yhp29c [aweight = weight]

preserve

*** Table 01, costs/benefits of voting

** fix constant sample, compare House primaries to House and Presidential
**   general elections for norms
qui regress electype_pres_yhp25b electype_pres_yhp25c electype_pres_yhp25i /*
  */electype_house_yhp26b electype_house_yhp26c electype_house_yhp26i /*
  */electype_hprim_yhp27b electype_hprim_yhp27c electype_hprim_yhp27i /*
  */[aweight = weight]
keep if e(sample)

* labels fixed for outsum table
label var electype_pres_yhp25b "My Vote Matters a Great Deal For Who Wins"
label var electype_pres_yhp25c "Outcome of Election Has Big Effect On My Life"
label var electype_pres_yhp25i "Easy to Figure Out Which Candidate to Vote For"

label var electype_house_yhp26b "My Vote Matters a Great Deal For Who Wins"
label var electype_house_yhp26c "Outcome of Election Has Big Effect On My Life"
label var electype_house_yhp26i "Easy to Figure Out Which Candidate to Vote For"

label var electype_hprim_yhp27b "My Vote Matters a Great Deal For Who Wins"
label var electype_hprim_yhp27c "Outcome of Election Has Big Effect On My Life"
label var electype_hprim_yhp27i "Easy to Figure Out Which Candidate to Vote For"

version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] using /*
  */Tables/Table01_ElectionTypeCalculusByKnowledge.out, bracket /*
  */addnote("Note: Proportion agreeing (strongly/somewhat), weighted.") /*
  */title("Table 1: Calculus of Voting Attitudes") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] if knowledge != . using /*
  */Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("House Primary, Knowledge Sample") append
version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using Tables/Table01_ElectionTypeCalculusByKnowledge, /*
  */bracket ctitle("House Primary, Low Knowledge") append
version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using Tables/Table01_ElectionTypeCalculusByKnowledge, /*
  */bracket ctitle("House Primary, High Knowledge") append

version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] using /*
  */Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] if knowledge != . using /*
  */Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("House General, Knowledge Sample") append
version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using Tables/Table01_ElectionTypeCalculusByKnowledge, /*
  */bracket ctitle("House General, Low Knowledge") append
version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using Tables/Table01_ElectionTypeCalculusByKnowledge, /*
  */bracket ctitle("House General, High Knowledge") append

version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] using /*
  */Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] if knowledge != . using /*
  */Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("Presidential General, Knowledge Sample") append
version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] if knowledge < 3 & knowledge != . /*
  */using Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] if knowledge > 2 & knowledge != . /*
  */using Tables/Table01_ElectionTypeCalculusByKnowledge, bracket /*
  */ctitle("Presidential General, High Knowledge") append

* alternative knowledge measure for appendix
version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge.out, bracket /*
  */addnote("Note: Proportion agreeing (strongly/somewhat), weighted.") /*
  */title("Table SA1: Calculus of Voting Attitudes Summary, Alternative Knowledge Measure") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("House Primary, Low Knowledge") append
version 9.2: outsum electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("House Primary, High Knowledge") append

version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("House General, Low Knowledge") append
version 9.2: outsum electype_house_yhp26b electype_house_yhp26c /*
  */electype_house_yhp26i [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("House General, High Knowledge") append

version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum electype_pres_yhp25b electype_pres_yhp25c /*
  */electype_pres_yhp25i [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA01_ElectionTypeCalculusByAltKnowledge, bracket /*
  */ctitle("Presidential General, High Knowledge") append

** differences of means reported in text
* importance: primary vs. House general
mean electype_hprim_yhp27c electype_house_yhp26c [aweight = weight]
lincom electype_hprim_yhp27c - electype_house_yhp26c
mean electype_hprim_yhp27c electype_house_yhp26c [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27c - electype_house_yhp26c
mean electype_hprim_yhp27c electype_house_yhp26c [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27c - electype_house_yhp26c
mean electype_hprim_yhp27c electype_house_yhp26c [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27c - electype_house_yhp26c

* importance: primary vs. Presidential general
mean electype_hprim_yhp27c electype_pres_yhp25c [aweight = weight]
lincom electype_hprim_yhp27c - electype_pres_yhp25c
mean electype_hprim_yhp27c electype_pres_yhp25c [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27c - electype_pres_yhp25c
mean electype_hprim_yhp27c electype_pres_yhp25c [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27c - electype_pres_yhp25c
mean electype_hprim_yhp27c electype_pres_yhp25c [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27c - electype_pres_yhp25c

* easy to figure out who to vote for: primary vs. House general
mean electype_hprim_yhp27i electype_house_yhp26i [aweight = weight]
lincom electype_hprim_yhp27i - electype_house_yhp26i
mean electype_hprim_yhp27i electype_house_yhp26i [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27i - electype_house_yhp26i
mean electype_hprim_yhp27i electype_house_yhp26i [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27i - electype_house_yhp26i
mean electype_hprim_yhp27i electype_house_yhp26i [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27i - electype_house_yhp26i

* easy to figure out who to vote for: primary vs. Presidential general
mean electype_hprim_yhp27i electype_pres_yhp25i [aweight = weight]
lincom electype_hprim_yhp27i - electype_pres_yhp25i
mean electype_hprim_yhp27i electype_pres_yhp25i [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27i - electype_pres_yhp25i
mean electype_hprim_yhp27i electype_pres_yhp25i [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27i - electype_pres_yhp25i
mean electype_hprim_yhp27i electype_pres_yhp25i [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27i - electype_pres_yhp25i

restore

********************************************************************************
**** Part 2: Social Norms about Participation Are Weaker and More Exclusionary
****   for Primary Elections
********************************************************************************

*** Table 02, analysis of social pressure/norms across election type

preserve

** fix constant sample, compare House primaries to House and Presidential
**   general elections for norms

qui regress socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f /*
  */socnorms_house_yhp32a socnorms_house_yhp32b socnorms_house_yhp32f /*
  */socnorms_pres_yhp31a socnorms_pres_yhp31b socnorms_pres_yhp31f
sum socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f /*
  */socnorms_house_yhp32a socnorms_house_yhp32b socnorms_house_yhp32f /*
  */socnorms_pres_yhp31a socnorms_pres_yhp31b socnorms_pres_yhp31f /*
  */[aweight = weight] if e(sample), sep(0)
keep if e(sample)

* labels fixed for outsum table
label var socnorms_hprim_yhp33a "If I Don't Vote, Family/Friends Disappointed"
label var socnorms_hprim_yhp33b /*
  */"If I Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_hprim_yhp33f "I Feel Bad If I Cannot Vote"

label var socnorms_house_yhp32a "If I Don't Vote, Family/Friends Disappointed"
label var socnorms_house_yhp32b /*
  */"If I Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_house_yhp32f "I Feel Bad If I Cannot Vote"

label var socnorms_pres_yhp31a "If I Don't Vote, Family/Friends Disappointed"
label var socnorms_pres_yhp31b /*
  */"If I Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_pres_yhp31f "I Feel Bad If I Cannot Vote"

version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] using /*
  */Tables/Table02_ElectionTypeNormsByKnowledge.out, bracket /*
  */addnote("Note: Proportion agreeing (strongly/somewhat), weighted") /*
  */title("Table 2: Social Norms Attitudes") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] if knowledge != . using /*
  */Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House Primary, Knowledge Sample") append
version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House Primary, Low Knowledge") append
version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House Primary, High Knowledge") append

version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] using /*
  */Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] if knowledge != . using /*
  */Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House General, Knowledge Sample") append
version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House General, Low Knowledge") append
version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("House General, High Knowledge") append

version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] using /*
  */Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] if knowledge != . using /*
  */Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("Presidential General, Knowledge Sample") append
version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] if knowledge < 3 & knowledge != . /*
  */using Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] if knowledge > 2 & knowledge != . /*
  */using Tables/Table02_ElectionTypeNormsByKnowledge, bracket /*
  */ctitle("Presidential General, High Knowledge") append

* alternative knowledge measure for appendix
version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge.out, bracket /*
  */addnote("Note: Proportion agreeingn (strongly/somewhat), weighted") /*
  */title("Table SA2: Social Norms Summary, Alternative Knowledge Measure") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("House Primary, Low Knowledge") append
version 9.2: outsum socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("House Primary, High Knowledge") append

version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("House General, Low Knowledge") append
version 9.2: outsum socnorms_house_yhp32a socnorms_house_yhp32b /*
  */socnorms_house_yhp32f [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("House General, High Knowledge") append

version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum socnorms_pres_yhp31a socnorms_pres_yhp31b /*
  */socnorms_pres_yhp31f [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA02_ElectionTypeNormsByAltKnowledge, bracket /*
  */ctitle("Presidential General, High Knowledge") append

** differences of means reported in text
* if don't vote: primary vs. House general
mean socnorms_hprim_yhp33a socnorms_house_yhp32a [aweight = weight]
lincom socnorms_hprim_yhp33a - socnorms_house_yhp32a
mean socnorms_hprim_yhp33a socnorms_house_yhp32a [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33a - socnorms_house_yhp32a
mean socnorms_hprim_yhp33a socnorms_house_yhp32a [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33a - socnorms_house_yhp32a
mean socnorms_hprim_yhp33a socnorms_house_yhp32a [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33a - socnorms_house_yhp32a

* if don't vote: primary vs. Presidential general
mean socnorms_hprim_yhp33a socnorms_pres_yhp31a [aweight = weight]
lincom socnorms_hprim_yhp33a - socnorms_pres_yhp31a
mean socnorms_hprim_yhp33a socnorms_pres_yhp31a [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33a - socnorms_pres_yhp31a
mean socnorms_hprim_yhp33a socnorms_pres_yhp31a [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33a - socnorms_pres_yhp31a
mean socnorms_hprim_yhp33a socnorms_pres_yhp31a [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33a - socnorms_pres_yhp31a

* stay informed: primary vs. House general
mean socnorms_hprim_yhp33b socnorms_house_yhp32b [aweight = weight]
lincom socnorms_hprim_yhp33b - socnorms_house_yhp32b
mean socnorms_hprim_yhp33b socnorms_house_yhp32b [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33b - socnorms_house_yhp32b
mean socnorms_hprim_yhp33b socnorms_house_yhp32b [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33b - socnorms_house_yhp32b
mean socnorms_hprim_yhp33b socnorms_house_yhp32b [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33b - socnorms_house_yhp32b

* stay informed: primary vs. Presidential general
mean socnorms_hprim_yhp33b socnorms_pres_yhp31b [aweight = weight]
lincom socnorms_hprim_yhp33b - socnorms_pres_yhp31b
mean socnorms_hprim_yhp33b socnorms_pres_yhp31b [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33b - socnorms_pres_yhp31b
mean socnorms_hprim_yhp33b socnorms_pres_yhp31b [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33b - socnorms_pres_yhp31b
mean socnorms_hprim_yhp33b socnorms_pres_yhp31b [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33b - socnorms_pres_yhp31b

* feel bad: primary vs. House general
mean socnorms_hprim_yhp33f socnorms_house_yhp32f [aweight = weight]
lincom socnorms_hprim_yhp33f - socnorms_house_yhp32f
mean socnorms_hprim_yhp33f socnorms_house_yhp32f [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33f - socnorms_house_yhp32f
mean socnorms_hprim_yhp33f socnorms_house_yhp32f [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33f - socnorms_house_yhp32f
mean socnorms_hprim_yhp33f socnorms_house_yhp32f [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33f - socnorms_house_yhp32f

* feel bad: primary vs. Presidential general
mean socnorms_hprim_yhp33f socnorms_pres_yhp31f [aweight = weight]
lincom socnorms_hprim_yhp33f - socnorms_pres_yhp31f
mean socnorms_hprim_yhp33f socnorms_pres_yhp31f [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33f - socnorms_pres_yhp31f
mean socnorms_hprim_yhp33f socnorms_pres_yhp31f [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33f - socnorms_pres_yhp31f
mean socnorms_hprim_yhp33f socnorms_pres_yhp31f [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33f - socnorms_pres_yhp31f

restore

*** Table SA16, analysis of social pressure/norms across election type,
***   coding DK as missing

preserve

** fix constant sample, compare House primaries to House and Presidential
**   general elections for norms

qui regress socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt socnorms_house_yhp32a_alt /*
  */socnorms_house_yhp32b_alt socnorms_house_yhp32f_alt /*
  */socnorms_pres_yhp31a_alt socnorms_pres_yhp31b_alt socnorms_pres_yhp31f_alt
sum socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt socnorms_house_yhp32a_alt /*
  */socnorms_house_yhp32b_alt socnorms_house_yhp32f_alt /*
  */socnorms_pres_yhp31a_alt socnorms_pres_yhp31b_alt /*
  */socnorms_pres_yhp31f_alt [aweight = weight] if e(sample), sep(0)
keep if e(sample)

* labels fixed for outsum table
label var socnorms_hprim_yhp33a_alt /*
  */"If I Don't Vote, Family/Friends Disappointed"
label var socnorms_hprim_yhp33b_alt /*
  */"If I Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_hprim_yhp33f_alt "I Feel Bad If I Cannot Vote"

label var socnorms_house_yhp32a_alt /*
  */"If I Don't Vote, Family/Friends Disappointed"
label var socnorms_house_yhp32b_alt /*
  */"If I Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_house_yhp32f_alt "I Feel Bad If I Cannot Vote"

label var socnorms_pres_yhp31a_alt /*
  */"If I Don't Vote, Family/Friends Disappointed"
label var socnorms_pres_yhp31b_alt /*
  */"If I Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_pres_yhp31f_alt "I Feel Bad If I Cannot Vote"

* by knowledge, as requested by reviewer
version 9.2: outsum socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt [aweight = weight] using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK.out, bracket /*
  */addnote("Note: Proportion agreeing (strongly/somewhat), weighted") /*
  */title("Table SA16: Social Norms Attitudes, Coding DK Responses as Missing") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt [aweight = weight] if knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House Primary, Knowledge Sample") append
version 9.2: outsum socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House Primary, Low Knowledge") append
version 9.2: outsum socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House Primary, High Knowledge") append

version 9.2: outsum socnorms_house_yhp32a_alt socnorms_house_yhp32b_alt /*
  */socnorms_house_yhp32f_alt [aweight = weight] using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum socnorms_house_yhp32a_alt socnorms_house_yhp32b_alt /*
  */socnorms_house_yhp32f_alt [aweight = weight] if knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House General, Knowledge Sample") append
version 9.2: outsum socnorms_house_yhp32a_alt socnorms_house_yhp32b_alt /*
  */socnorms_house_yhp32f_alt [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House General, Low Knowledge") append
version 9.2: outsum socnorms_house_yhp32a_alt socnorms_house_yhp32b_alt /*
  */socnorms_house_yhp32f_alt [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("House General, High Knowledge") append

version 9.2: outsum socnorms_pres_yhp31a_alt socnorms_pres_yhp31b_alt /*
  */socnorms_pres_yhp31f_alt [aweight = weight] using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum socnorms_pres_yhp31a_alt socnorms_pres_yhp31b_alt /*
  */socnorms_pres_yhp31f_alt [aweight = weight] if knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("Presidential General, Knowledge Sample") append
version 9.2: outsum socnorms_pres_yhp31a_alt socnorms_pres_yhp31b_alt /*
  */socnorms_pres_yhp31f_alt [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum socnorms_pres_yhp31a_alt socnorms_pres_yhp31b_alt /*
  */socnorms_pres_yhp31f_alt [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using /*
  */Tables/TableSA16_ElectionTypeNormsByKnowledgeExcludingDK, bracket /*
  */ctitle("Presidential General, High Knowledge") append

** difference-of-means tests analogous to those reported in text
* if don't vote: primary vs. House general
mean socnorms_hprim_yhp33a_alt socnorms_house_yhp32a_alt [aweight = weight]
lincom socnorms_hprim_yhp33a_alt - socnorms_house_yhp32a_alt
mean socnorms_hprim_yhp33a_alt socnorms_house_yhp32a_alt [aweight = weight] /*
  */if knowledge != .
lincom socnorms_hprim_yhp33a_alt - socnorms_house_yhp32a_alt
mean socnorms_hprim_yhp33a_alt socnorms_house_yhp32a_alt [aweight = weight] /*
  */if knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33a_alt - socnorms_house_yhp32a_alt
mean socnorms_hprim_yhp33a_alt socnorms_house_yhp32a_alt [aweight = weight] /*
  */if knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33a_alt - socnorms_house_yhp32a_alt

* if don't vote: primary vs. Presidential general
mean socnorms_hprim_yhp33a_alt socnorms_pres_yhp31a_alt [aweight = weight]
lincom socnorms_hprim_yhp33a_alt - socnorms_pres_yhp31a_alt
mean socnorms_hprim_yhp33a_alt socnorms_pres_yhp31a_alt [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33a_alt - socnorms_pres_yhp31a_alt
mean socnorms_hprim_yhp33a_alt socnorms_pres_yhp31a_alt [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33a_alt - socnorms_pres_yhp31a_alt
mean socnorms_hprim_yhp33a_alt socnorms_pres_yhp31a_alt [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33a_alt - socnorms_pres_yhp31a_alt

* stay informed: primary vs. House general
mean socnorms_hprim_yhp33b_alt socnorms_house_yhp32b_alt [aweight = weight]
lincom socnorms_hprim_yhp33b_alt - socnorms_house_yhp32b_alt
mean socnorms_hprim_yhp33b_alt socnorms_house_yhp32b_alt [aweight = weight] /*
  */if knowledge != .
lincom socnorms_hprim_yhp33b_alt - socnorms_house_yhp32b_alt
mean socnorms_hprim_yhp33b_alt socnorms_house_yhp32b_alt [aweight = weight] /*
  */if knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33b_alt - socnorms_house_yhp32b_alt
mean socnorms_hprim_yhp33b_alt socnorms_house_yhp32b_alt [aweight = weight] /*
  */if knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33b_alt - socnorms_house_yhp32b_alt

* stay informed: primary vs. Presidential general
mean socnorms_hprim_yhp33b_alt socnorms_pres_yhp31b_alt [aweight = weight]
lincom socnorms_hprim_yhp33b_alt - socnorms_pres_yhp31b_alt
mean socnorms_hprim_yhp33b_alt socnorms_pres_yhp31b_alt [aweight = weight] /*
  */if knowledge != .
lincom socnorms_hprim_yhp33b_alt - socnorms_pres_yhp31b_alt
mean socnorms_hprim_yhp33b_alt socnorms_pres_yhp31b_alt [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33b_alt - socnorms_pres_yhp31b_alt
mean socnorms_hprim_yhp33b_alt socnorms_pres_yhp31b_alt [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33b_alt - socnorms_pres_yhp31b_alt

* feel bad: primary vs. House general
mean socnorms_hprim_yhp33f_alt socnorms_house_yhp32f_alt [aweight = weight]
lincom socnorms_hprim_yhp33f_alt - socnorms_house_yhp32f_alt
mean socnorms_hprim_yhp33f_alt socnorms_house_yhp32f_alt [aweight = weight] /*
  */if knowledge != .
lincom socnorms_hprim_yhp33f_alt - socnorms_house_yhp32f_alt
mean socnorms_hprim_yhp33f_alt socnorms_house_yhp32f_alt [aweight = weight] /*
  */if knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33f_alt - socnorms_house_yhp32f_alt
mean socnorms_hprim_yhp33f_alt socnorms_house_yhp32f_alt [aweight = weight] /*
  */if knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33f_alt - socnorms_house_yhp32f_alt

* feel bad: primary vs. Presidential general
mean socnorms_hprim_yhp33f_alt socnorms_pres_yhp31f_alt [aweight = weight]
lincom socnorms_hprim_yhp33f_alt - socnorms_pres_yhp31f_alt
mean socnorms_hprim_yhp33f_alt socnorms_pres_yhp31f_alt [aweight = weight] if /*
  */knowledge != .
lincom socnorms_hprim_yhp33f_alt - socnorms_pres_yhp31f_alt
mean socnorms_hprim_yhp33f_alt socnorms_pres_yhp31f_alt [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom socnorms_hprim_yhp33f_alt - socnorms_pres_yhp31f_alt
mean socnorms_hprim_yhp33f_alt socnorms_pres_yhp31f_alt [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom socnorms_hprim_yhp33f_alt - socnorms_pres_yhp31f_alt

restore

** civic duty battery by election type, reported in footnote 5
preserve

qui regress civicduty_yhp24f civicduty_yhp24c civicduty_yhp24a
keep if e(sample)
sum civicduty_yhp24f civicduty_yhp24c civicduty_yhp24a [aweight = weight]

* difference of means reported in text:

* Civic duty battery (primary to House general).
mean civicduty_yhp24f civicduty_yhp24c [aweight = weight]
lincom civicduty_yhp24f - civicduty_yhp24c

* Civic duty battery: primary vs. Presidential general
mean civicduty_yhp24f civicduty_yhp24a [aweight = weight]
lincom civicduty_yhp24f - civicduty_yhp24a

restore

*** Table SA05, social norms about voting and voting in party primary, by PID

preserve

** fix constant sample, compare across party id categories
qui regress socnorms_hprim_yhp33a primnorms_yhp30d pid7_alt
keep if e(sample)

forvalues ctr = 1(1)7 {
  local templabel : label (pid7_alt) `ctr'
  if `ctr' == 1 {
    version 9.2: outsum socnorms_hprim_yhp33a primnorms_yhp30d if /*
      */pid7_alt == `ctr' [weight = weight] using /*
      */Tables/TableSA05_SocialNormsAboutPrimaryVotingByPID.out, bracket /*
      */ctitle("`templabel'") /*
      */addnote("Note: Proportion agreeing (strongly/somewhat), weighted") /*
      */title("Table SA5: Social Norms Attitudes, by Party Identification") /*
      */replace
  }
  else {
    version 9.2: outsum socnorms_hprim_yhp33a primnorms_yhp30d if /*
      */pid7_alt == `ctr' [weight = weight] using /*
      */Tables/TableSA05_SocialNormsAboutPrimaryVotingByPID, bracket /*
      */ctitle("`templabel'") append
  }
}

** differences of means reported in text
* for Dems: strong partisans vs. leaners
gen demID = 1 if pid7_alt == 1
replace demID = 0 if pid7_alt == 3
svyset [pweight = weight]
svy: mean primnorms_yhp30d, over(demID)
test [primnorms_yhp30d]0 = [primnorms_yhp30d]1

* for Reps: strong partisans vs. leaners
gen repID = 1 if pid7_alt == 7
replace repID = 0 if pid7_alt == 5
svy: mean primnorms_yhp30d, over(repID)
test [primnorms_yhp30d]0 = [primnorms_yhp30d]1

restore

*** Table 3, who ought to vote in a primary

preserve

** fix constant sample, compare across knowledge levels

qui regress primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight]
keep if e(sample)
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] using /*
  */Tables/Table03_PrimaryWhoShouldVoteNormsByKnowledge.out, bracket /*
  */ctitle("Proportion Agreeing, Weighted, Full Sample") /*
  */title("Table 3: Exclusionary Norms About Primary Voting") replace
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] if knowledge != . using /*
  */Tables/Table03_PrimaryWhoShouldVoteNormsByKnowledge, bracket /*
  */ctitle("Proportion Agreeing, Weighted, Knowledge Sample") append
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] if knowledge < 3 & knowledge != . /*
  */using Tables/Table03_PrimaryWhoShouldVoteNormsByKnowledge, bracket /*
  */ctitle("Proportion Agreeing, Weighted, Low-Knowledge Sample") append
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] if knowledge > 2 & knowledge != . /*
  */using Tables/Table03_PrimaryWhoShouldVoteNormsByKnowledge, bracket /*
  */ctitle("Proportion Agreeing, Weighted, High-Knowledge Sample") append

*** Table SA3, exclusionary norms attitudes
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] using /*
  */Tables/TableSA03_PrimaryWhoShouldVoteNormsByAltKnowledge.out, bracket /*
  */ctitle("Proportion Agreeing, Weighted, Full Sample") /*
  */title("Table SA3: Exclusionary Norms Attitudes, Alternative Knowledge Measure") /*
  */replace
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA03_PrimaryWhoShouldVoteNormsByAltKnowledge, bracket /*
  */ctitle("Proportion Agreeing, Weighted, Low Knowledge") append
version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA03_PrimaryWhoShouldVoteNormsByAltKnowledge, bracket /*
  */ctitle("Proportion Agreeing, Weighted, High Knowledge") append

*** Table SA6, Table 2 broken down by party id
forvalues ctr = 1(1)7 {
  local templabel : label (pid7_alt) `ctr'
  if `ctr' == 1 {
    version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
	  */primnorms_yhp30e if pid7_alt == `ctr' [weight = weight] using /*
	  */Tables/TableSA06_ExclusionaryNormsAboutPrimaryVotingByPID.out, /*
	  */bracket ctitle("`templabel'") /*
	  */addnote("Proportion agreeing (strongly/somewhat), weighted") /*
	  */title("Table SA6: Exclusionary Norms Attitudes, by Party Identification") /*
	  */replace
  }
  else {
    version 9.2: outsum primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
	  */primnorms_yhp30e if pid7_alt == `ctr' [weight = weight] using /*
	  */Tables/TableSA06_ExclusionaryNormsAboutPrimaryVotingByPID, bracket /*
	  */ctitle("`templabel'") append
  }
}

* create primary system variable (open vs. all others)
gen open_primary = 0
replace open_primary = 1 if primaryrule == 0

** differences of means reported in footnote 6: exclusionary norms differences by
**   primary type
svyset [pweight = weight]

* only those committed to party's candidate should vote in primary
svy: mean primnorms_yhp30a, over(open_primary)
test [primnorms_yhp30a]1 = [primnorms_yhp30a]0

* only those who strongly identify with party should vote in primary
svy: mean primnorms_yhp30b, over(open_primary)
test [primnorms_yhp30b]1 = [primnorms_yhp30b]0

* Independents should not vote in primaries:
svy: mean primnorms_yhp30c, over(open_primary)
test [primnorms_yhp30c]1 = [primnorms_yhp30c]0

* it would be wrong to vote in other party's primary
svy: mean primnorms_yhp30e, over(open_primary)
test [primnorms_yhp30e]1 = [primnorms_yhp30e]0

** differences of means reported in footnote 6: social norms differences by
**   primary type

* if I don't vote, family/friends disappointed
svy: mean socnorms_hprim_yhp33a, over(open_primary)
test [socnorms_hprim_yhp33a]1 = [socnorms_hprim_yhp33a]0

* if I don't stay informed, family/friends disappointed
svy: mean socnorms_hprim_yhp33b, over(open_primary)
test [socnorms_hprim_yhp33b]1 = [socnorms_hprim_yhp33b]0

* I feel bad if I cannot vote
svy: mean socnorms_hprim_yhp33f, over(open_primary)
test [socnorms_hprim_yhp33f]1 = [socnorms_hprim_yhp33f]0

** conditioning effects of primary rules on social/exclusionary norms reported in
**   footnote 6 (bivariate regression models)

* only those committed to party's candidate should vote in primary
gen primnorms_yhp30a_primrule = primnorms_yhp30a*open_primary
reg voted_primaries_10or12 primnorms_yhp30a open_primary /*
  */primnorms_yhp30a_primrule [aweight = weight], robust

* only those who strongly identify with party should vote in primary
gen primnorms_yhp30b_primrule = primnorms_yhp30b * open_primary
reg voted_primaries_10or12 primnorms_yhp30b open_primary /*
  */primnorms_yhp30b_primrule [aweight = weight], robust

* Independents should not vote in primaries
gen primnorms_yhp30c_primrule = primnorms_yhp30c * open_primary
reg voted_primaries_10or12 primnorms_yhp30c open_primary /*
  */primnorms_yhp30c_primrule [aweight = weight], robust

* it would be wrong to vote in other party's primary
gen primnorms_yhp30e_primrule = primnorms_yhp30e * open_primary
reg voted_primaries_10or12 primnorms_yhp30e open_primary /*
  */primnorms_yhp30e_primrule [aweight = weight], robust

* if I don't vote, family/friends disappointed
gen socnorms_hprim_yhp33a_primrule = socnorms_hprim_yhp33a * open_primary
reg voted_primaries_10or12 socnorms_hprim_yhp33a open_primary /*
  */socnorms_hprim_yhp33a_primrule [aweight = weight], robust

* if I don't stay informed, family/friends disappointed
gen socnorms_hprim_yhp33b_primrule = socnorms_hprim_yhp33b * open_primary
reg voted_primaries_10or12 socnorms_hprim_yhp33b open_primary /*
  */socnorms_hprim_yhp33b_primrule [aweight = weight], robust

* i feel bad if i cannot vote
gen socnorms_hprim_yhp33f_primrule = socnorms_hprim_yhp33f * open_primary
reg voted_primaries_10or12 socnorms_hprim_yhp33f open_primary /*
  */socnorms_hprim_yhp33f_primrule [aweight = weight], robust

restore

********************************************************************************
**** Part 3: Deference to others who know/care more
********************************************************************************

** crosstabs of responses
tab yhp15 [aweight = weight]
tab yhp16 [aweight = weight]
tab yhp14 [aweight = weight]

** Pearson's rho reported in footnote 7
pwcorr yhp15 yhp16 [aweight = weight], sig

*** Table 4, deference attitudes

preserve

*** fix constant sample, compare House primaries to House and Presidential
***   general elections for knowing/caring/deferring

qui regress electype_hprim_yhp27a electype_hprim_yhp27h electype_hprim_yhp27i /*
  */electype_hprim_yhp27e electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26i electype_house_yhp26e electype_pres_yhp25a /*
  */electype_pres_yhp25h electype_pres_yhp25i electype_pres_yhp25e /*
  */electype_hprim_yhp27c electype_house_yhp26c electype_pres_yhp25c /*
  */[aweight = weight]
keep if e(sample)

label var electype_hprim_yhp27a /*
  */"I Am Well Qualified to Choose Candidate to Vote For"
label var electype_hprim_yhp27h "I Know a Great Deal About Each Candidate"
label var electype_hprim_yhp27i "Easy to Figure Out Which Candidate to Vote For"
label var electype_hprim_yhp27e /*
  */"If I Don't Vote, Others Will Do Good Job of Picking Candidate"

label var electype_house_yhp26a /*
  */"I Am Well Qualified to Choose Candidate to Vote For"
label var electype_house_yhp26h "I Know a Great Deal About Each Candidate"
label var electype_house_yhp26i "Easy to Figure Out Which Candidate to Vote For"
label var electype_house_yhp26e /*
  */"If I Don't Vote, Others Will Do Good Job of Picking Candidate"

label var electype_pres_yhp25a /*
  */"I Am Well Qualified to Choose Candidate to Vote For"
label var electype_pres_yhp25h "I Know a Great Deal About Each Candidate"
label var electype_pres_yhp25i "Easy to Figure Out Which Candidate to Vote For"
label var electype_pres_yhp25e /*
  */"If I Don't Vote, Others Will Do Good Job of Picking Candidate"

label var electype_hprim_yhp27c "Outcome Has a Big Effect On My Life"
label var electype_house_yhp26c "Outcome Has a Big Effect On My Life"
label var electype_pres_yhp25c "Outcome Has a Big Effect On My Life"

version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] using /*
  */Tables/Table04_DeferenceNormsByKnowledge.out, bracket /*
  */title("Table 4: Deference Attitudes") /*
  */addnote("Note: Proportion agreeing (strongly/somewhat), weighted") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] if knowledge != . using /*
  */Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House Primary, Knowledge Sample") append
version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House Primary, Low Knowledge") append
version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House Primary, High Knowledge") append

version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] using /*
  */Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] if knowledge != . using /*
  */Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House General, Knowledge Sample") append
version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] if knowledge < 3 & /*
  */knowledge != . using Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House General, Low Knowledge") append
version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] if knowledge > 2 & /*
  */knowledge != . using Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("House General, High Knowledge") append

version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] using /*
  */Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] if knowledge != . using /*
  */Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("Presidential General, Knowledge Sample") append
version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] if knowledge < 3 & knowledge != . /*
  */using Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] if knowledge > 2 & knowledge != . /*
  */using Tables/Table04_DeferenceNormsByKnowledge, bracket /*
  */ctitle("Presidential General, High Knowledge") append

*** Table SA4, deference attitudes, alternative knowledge measure
version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge.out, bracket /*
  */title("Table SA4: Deference Attitudes, Alternative Knowledge Measure") /*
  */addnote("Note: Proportion agreeing (strongly/somewhat), weighted") /*
  */ctitle("House Primary, Full Sample") replace
version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("House Primary, Low Knowledge") append
version 9.2: outsum electype_hprim_yhp27a electype_hprim_yhp27h /*
  */electype_hprim_yhp27e [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("House Primary, High Knowledge") append

version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("House General, Full Sample") append
version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("House General, Low Knowledge") append
version 9.2: outsum electype_house_yhp26a electype_house_yhp26h /*
  */electype_house_yhp26e [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("House General, High Knowledge") append

version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("Presidential General, Full Sample") append
version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] if knowledge_alt < 3 using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("Presidential General, Low Knowledge") append
version 9.2: outsum electype_pres_yhp25a electype_pres_yhp25h /*
  */electype_pres_yhp25e [aweight = weight] if knowledge_alt > 2 using /*
  */Tables/TableSA04_DeferenceNormsByAltKnowledge, bracket /*
  */ctitle("Presidential General, High Knowledge") append

** differences of means reported in text
* well qualified to choose candidate: primary vs. House general
mean electype_hprim_yhp27a electype_house_yhp26a [aweight = weight]
lincom electype_hprim_yhp27a - electype_house_yhp26a
mean electype_hprim_yhp27a electype_house_yhp26a [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27a - electype_house_yhp26a
mean electype_hprim_yhp27a electype_house_yhp26a [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27a - electype_house_yhp26a
mean electype_hprim_yhp27a electype_house_yhp26a [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27a - electype_house_yhp26a

* well qualified to choose candidate: primary vs. Presidential general
mean electype_hprim_yhp27a electype_pres_yhp25a [aweight = weight]
lincom electype_hprim_yhp27a - electype_pres_yhp25a
mean electype_hprim_yhp27a electype_pres_yhp25a [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27a - electype_pres_yhp25a
mean electype_hprim_yhp27a electype_pres_yhp25a [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27a - electype_pres_yhp25a
mean electype_hprim_yhp27a electype_pres_yhp25a [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27a - electype_pres_yhp25a

* know a great deal about each candidate: primary vs. House general
mean electype_hprim_yhp27h electype_house_yhp26h [aweight = weight]
lincom electype_hprim_yhp27h - electype_house_yhp26h
mean electype_hprim_yhp27h electype_house_yhp26h [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27h - electype_house_yhp26h
mean electype_hprim_yhp27h electype_house_yhp26h [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27h - electype_house_yhp26h
mean electype_hprim_yhp27h electype_house_yhp26h [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27h - electype_house_yhp26h

* know a great deal about each candidate: primary vs. Presidential general
mean electype_hprim_yhp27h electype_pres_yhp25h [aweight = weight]
lincom electype_hprim_yhp27h - electype_pres_yhp25h
mean electype_hprim_yhp27h electype_pres_yhp25h [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27h - electype_pres_yhp25h
mean electype_hprim_yhp27h electype_pres_yhp25h [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27h - electype_pres_yhp25h
mean electype_hprim_yhp27h electype_pres_yhp25h [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27h - electype_pres_yhp25h

* if I don't vote, others will do a good job: primary vs. House general
mean electype_hprim_yhp27e electype_house_yhp26e [aweight = weight]
lincom electype_hprim_yhp27e - electype_house_yhp26e
mean electype_hprim_yhp27e electype_house_yhp26e [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27e - electype_house_yhp26e
mean electype_hprim_yhp27e electype_house_yhp26e [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27e - electype_house_yhp26e
mean electype_hprim_yhp27e electype_house_yhp26e [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27e - electype_house_yhp26e

* if I don't vote, others will do a good job, primary vs. Presidential general
mean electype_hprim_yhp27e electype_pres_yhp25e [aweight = weight]
lincom electype_hprim_yhp27e - electype_pres_yhp25e
mean electype_hprim_yhp27e electype_pres_yhp25e [aweight = weight] if /*
  */knowledge != .
lincom electype_hprim_yhp27e - electype_pres_yhp25e
mean electype_hprim_yhp27e electype_pres_yhp25e [aweight = weight] if /*
  */knowledge < 3 & knowledge != .
lincom electype_hprim_yhp27e - electype_pres_yhp25e
mean electype_hprim_yhp27e electype_pres_yhp25e [aweight = weight] if /*
  */knowledge > 2 & knowledge != .
lincom electype_hprim_yhp27e - electype_pres_yhp25e

gen highknowledge = knowledge > 2
* well qualified to choose candidate, House primary: low- vs. high-knowledge
mean electype_hprim_yhp27a [aweight = weight], over(highknowledge)
lincom [electype_hprim_yhp27a]0 - [electype_hprim_yhp27a]1

* well qualified to choose candidate, House general: low- vs. high-knowledge
mean electype_house_yhp26a [aweight = weight], over(highknowledge)
lincom [electype_house_yhp26a]0 - [electype_house_yhp26a]1

* well qualified to choose candidate, presidential general: low- vs.
*   high-knowledge
mean electype_pres_yhp25a [aweight = weight], over(highknowledge)
lincom [electype_pres_yhp25a]0 - [electype_pres_yhp25a]1

* know a great deal about candidates, House primary: low- vs. high-knowledge
mean electype_hprim_yhp27h [aweight = weight], over(highknowledge)
lincom [electype_hprim_yhp27h]0 - [electype_hprim_yhp27h]1

* know a great deal about candidates, House general: low- vs. high-knowledge
mean electype_house_yhp26h [aweight = weight], over(highknowledge)
lincom [electype_house_yhp26h]0 - [electype_house_yhp26h]1

* know a great deal about candidates, presidential general: low- vs.
*   high-knowledge
mean electype_pres_yhp25h [aweight = weight], over(highknowledge)
lincom [electype_pres_yhp25h]0 - [electype_pres_yhp25h]1

* easy to figure out, House primary: low- vs. high-knowledge
mean electype_hprim_yhp27i [aweight = weight], over(highknowledge)
lincom [electype_hprim_yhp27i]0 - [electype_hprim_yhp27i]1

* easy to figure out, House general: low- vs. high-knowledge
mean electype_house_yhp26i [aweight = weight], over(highknowledge)
lincom [electype_house_yhp26i]0 - [electype_house_yhp26i]1

* easy to figure out, presidential general: low- vs. high-knowledge
mean electype_pres_yhp25i [aweight = weight], over(highknowledge)
lincom [electype_pres_yhp25i]0 - [electype_pres_yhp25i]1

* others do good job, House primary: low- vs. high-knowledge
mean electype_hprim_yhp27e [aweight = weight], over(highknowledge)
lincom [electype_hprim_yhp27e]0 - [electype_hprim_yhp27e]1

* others do good job, House general: low- vs. high-knowledge
mean electype_house_yhp26e [aweight = weight], over(highknowledge)
lincom [electype_house_yhp26e]0 - [electype_house_yhp26e]1

* others do good job, presidential general: low- vs. high-knowledge
mean electype_pres_yhp25e [aweight = weight], over(highknowledge)
lincom [electype_pres_yhp25e]0 - [electype_pres_yhp25e]1

* outcome of election has big effect, House primary: low- vs. high-knowledge
mean electype_hprim_yhp27c [aweight = weight], over(highknowledge)
lincom [electype_hprim_yhp27c]0 - [electype_hprim_yhp27c]1

* outcome of election has big effect, House general: low- vs. high-knowledge
mean electype_house_yhp26c [aweight = weight], over(highknowledge)
lincom [electype_house_yhp26c]0 - [electype_house_yhp26c]1

* outcome of election has big effect, presidential general: low- vs.
*   high-knowledge
mean electype_pres_yhp25c [aweight = weight], over(highknowledge)
lincom [electype_pres_yhp25c]0 - [electype_pres_yhp25c]1

restore

********************************************************************************
**** Part 4: Attitudes and Voting
********************************************************************************

preserve

** drop binary forms of agree-disagree variables to use full-scale versions for
**   regression

drop *_hprim_*

** turnout outcome variable
label var voted_primaries_10or12 "Voted in Either the 2008 or 2012 Primary"

** calculus of voting items
* yhp27: house primary (note that original labels from YouGov are wrong)
foreach var of varlist yhp27* yhp28* {
  recode `var' (1 = 1) (2 = .67) (3 = .33) (4 = 0) (* = .), /*
    */gen(electype_hprim_`var')
}
gen p_times_b = electype_hprim_yhp27b * electype_hprim_yhp27c
label var electype_hprim_yhp27b "My Vote Matters"
label var electype_hprim_yhp27c "Outcome Important"
label var electype_hprim_yhp27i "Easy to Figure Out Who to Vote For"
label var p_times_b "My Vote Matters * Outcome Important"

* norms items
foreach var of varlist yhp33* {
  recode `var' (1 = 1) (2 = .75) (3 = .25) (4 = 0) (5 = .5) (* = .), /*
    */gen(socnorms_hprim_`var')
}
label var socnorms_hprim_yhp33a /*
  */"House Prim. - If Don't Vote, Family/Friends Disappointed"
label var socnorms_hprim_yhp33b /*
  */"House Prim. - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_hprim_yhp33c "House Prim. - Most of My Family/Friends Vote"
label var socnorms_hprim_yhp33d /*
  */"House Prim. - Most of My Family/Friends Stay Informed"
label var socnorms_hprim_yhp33e /*
  */"House Prim. - Family/Friends Will Find Out if I Don't Vote"
label var socnorms_hprim_yhp33f "House Prim. - I Feel Bad if I Cannot Vote"
label var socnorms_hprim_yhp33g /*
  */"House Prim. - It is Important to Turn Out and Vote"

alpha socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f 
pwcorr socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f, sig
gen prim_soc_norms_scale = (socnorms_hprim_yhp33a + socnorms_hprim_yhp33b + /*
  */socnorms_hprim_yhp33f) / 3
label var prim_soc_norms_scale "Social Pressure/Norms Scale (0 - 1)"

alpha primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c primnorms_yhp30e
pwcorr primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c primnorms_yhp30e, sig
gen prim_exclusion_scale = (primnorms_yhp30a + primnorms_yhp30b + /*
  */primnorms_yhp30c + primnorms_yhp30e) / 4
label var prim_exclusion_scale "Exclusive Primary Norms (0 - 1)"

gen Z_pidstrong_excnorms = (pid7_alt == 1 | pid7_alt == 7) * /*
  */prim_exclusion_scale
gen Z_pidweak_excnorms = (pid7_alt == 2 | pid7_alt == 6) * prim_exclusion_scale
gen Z_pidlean_excnorms = (pid7_alt == 3 | pid7_alt == 5) * prim_exclusion_scale
gen Z_pidindpt_excnorms = (pid7_alt == 4) * prim_exclusion_scale

label var Z_pidstrong_excnorms /*
  */"Strong Partisan X Exclusive Primary Norms (0 - 1)"
label var Z_pidweak_excnorms "Weak Partisan X Exclusive Primary Norms (0 - 1)"
label var Z_pidlean_excnorms "Leaning Partisan X Exclusive Primary Norms (0-1)"
label var Z_pidindpt_excnorms /*
  */"Independent/Other X Exclusive Primary Norms (0 - 1)"

** deference items
* I can defer, * electype_hprim_yhp27e
label var electype_hprim_yhp27e /*
  */"If I Don't Vote, Others Will Do Good Job of Picking Candidate"

* interactions with importance/easy to figure out and can trust
gen S_cantrustvoters_care = electype_hprim_yhp27e * (electype_hprim_yhp27c)
label var S_cantrustvoters_care "Can Trust Voters x Outcome Important"
gen S_cantrustvoters_know = electype_hprim_yhp27e * (electype_hprim_yhp27i)
label var S_cantrustvoters_know /*
  */"Can Trust Voters x Easy to Figure Out Who to Vote For"

* fix constant sample for remaining regressions
qui regress voted_primaries_10or12 electype_hprim_yhp27b p_times_b /*
  */electype_hprim_yhp27c electype_hprim_yhp27i prim_soc_norms_scale /*
  */prim_exclusion_scale electype_hprim_yhp27e D_* [aweight = weight], robust
keep if e(sample)

sum voted_primaries_10or12 electype_hprim_yhp27b p_times_b /*
  */electype_hprim_yhp27c electype_hprim_yhp27i prim_soc_norms_scale /*
  */prim_exclusion_scale electype_hprim_yhp27e D_* [aweight = weight]

*** Tables 5 and SA7, correlates of primary participation
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label addstat(Controls, 0) /*
  */title("Table 5: Correlates of Primary Election Participation Among General Election Voters") /*
  */replace
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label /*
  */title("Table SA7: Correlates of Primary Election Participation Among General Election Voters, with Controls Displayed") /*
  */replace
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i knowledge D_* [aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label drop(knowledge D_educ2 D_educ3 D_educ4 D_age D_age2 /*
  */D_isfemale D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 /*
  */D_inc5 D_incrf) addstat(Controls, 1) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append

* regression results reported in footnote 9
regress voted_primaries_10or12 electype_hprim_yhp27b p_times_b /*
  */electype_hprim_yhp27c electype_hprim_yhp27i [aweight = weight], robust
regress voted_primaries_10or12 electype_hprim_yhp27b p_times_b /*
  */electype_hprim_yhp27c electype_hprim_yhp27i knowledge D_* /*
  */[aweight = weight], robust

regress voted_primaries_10or12 prim_soc_norms_scale prim_exclusion_scale /*
  */[aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label addstat(Controls, 0) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append
regress voted_primaries_10or12 prim_soc_norms_scale prim_exclusion_scale /*
  */knowledge D_* [aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label drop(knowledge D_educ2 D_educ3 D_educ4 D_age D_age2 /*
  */D_isfemale D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 /*
  */D_inc5 D_incrf) addstat(Controls, 1) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel bracket /*
  */aster(se) dec(3) label append

regress voted_primaries_10or12 prim_soc_norms_scale Z_* D_pidstr* /*
  */[aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label addstat(Controls, 0) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel bracket /*
  */aster(se) dec(3) label append
regress voted_primaries_10or12 prim_soc_norms_scale knowledge Z_* D_* /*
  */[aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label drop(knowledge D_educ2 D_educ3 D_educ4 D_age D_age2 /*
  */D_isfemale D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 /*
  */D_inc5 D_incrf) addstat(Controls, 1) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append
lincom Z_pidstrong_excnorms - Z_pidweak_excnorms

regress voted_primaries_10or12 electype_hprim_yhp27e [aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label addstat(Controls, 0) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append
regress voted_primaries_10or12 electype_hprim_yhp27e knowledge D_* /*
  */[aweight = weight], robust
outreg2 using Tables/Table05_PredictingVoting1, excel bracket aster(se) /*
  */dec(3) label drop(knowledge D_educ2 D_educ3 D_educ4 D_age D_age2 /*
  */D_isfemale D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 /*
  */D_incrf) addstat(Controls, 1) append
outreg2 using Tables/TableSA07_PredictiveVoting1WithControls, excel bracket /*
  */aster(se) dec(3) label append

*** Table 5 analysis with a common sample
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i knowledge D_* [aweight = weight], robust
gen tab5reducedsample = e(sample)

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight] if tab5reducedsample == 1, robust
outreg2 using Tables/TableSA20_PredictiveVoting1ReducedSample, excel bracket /*
  */aster(se) dec(3) label /*
  */title("Table SA20: Correlates of Primary Election Participation Among General Election Voters, Complete Control Sample") /*
  */replace
regress voted_primaries_10or12 prim_soc_norms_scale prim_exclusion_scale /*
  */[aweight = weight] if tab5reducedsample == 1, robust
outreg2 using Tables/TableSA20_PredictiveVoting1ReducedSample, excel bracket /*
  */aster(se) dec(3) label append
regress voted_primaries_10or12 prim_soc_norms_scale Z_* D_pidstr* /*
  */[aweight = weight] if tab5reducedsample == 1, robust
outreg2 using Tables/TableSA20_PredictiveVoting1ReducedSample, excel bracket /*
  */aster(se) dec(3) label append
regress voted_primaries_10or12 electype_hprim_yhp27e [aweight = weight] if /*
  */tab5reducedsample == 1, robust
outreg2 using Tables/TableSA20_PredictiveVoting1ReducedSample, excel bracket /*
  */aster(se) dec(3) label append

*** exclusionary norms results broken down by partisanship
regress voted_primaries_10or12 prim_exclusion_scale [aweight = weight] if /*
  */pid7 < 4, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */title("Table SA8: Predicting Voting by Exclusionary Norms, Broken Down by Partisanship") /*
  */ctitle("Democrats") replace
regress voted_primaries_10or12 prim_exclusion_scale [aweight = weight] if /*
  */pid7 > 4 & pid7 < 8, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Republicans") append
regress voted_primaries_10or12 prim_exclusion_scale D_pidstr2 D_pidstr3 /*
  */knowledge D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale D_racenotwhite /*
  */D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf /*
  */[aweight = weight] if pid7 < 4, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Democrats") append
regress voted_primaries_10or12 prim_exclusion_scale D_pidstr2 D_pidstr3 /*
  */knowledge D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale D_racenotwhite /*
  */D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf /*
  */[aweight = weight] if pid7 > 4 & pid7 < 8, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Republicans") append
regress voted_primaries_10or12 prim_exclusion_scale D_pidstr2 D_pidstr3 /*
  */Z_pidweak_excnorms Z_pidlean_excnorms [aweight = weight] if pid7 < 4, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Democrats") append
regress voted_primaries_10or12 prim_exclusion_scale D_pidstr2 D_pidstr3 /*
  */Z_pidweak_excnorms Z_pidlean_excnorms [aweight = weight] if pid7 > 4 & /*
  */pid7 < 8, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Republicans") append
regress voted_primaries_10or12 prim_exclusion_scale D_pidstr2 D_pidstr3 /*
  */Z_pidweak_excnorms Z_pidlean_excnorms knowledge D_educ2 D_educ3 D_educ4 /*
  */D_age D_age2 D_isfemale D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 /*
  */D_inc4 D_inc5 D_incrf [aweight = weight] if pid7 < 4, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Democrats") append
regress voted_primaries_10or12 prim_exclusion_scale D_pidstr2 D_pidstr3 /*
  */Z_pidweak_excnorms Z_pidlean_excnorms knowledge D_educ2 D_educ3 D_educ4 /*
  */D_age D_age2 D_isfemale D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 /*
  */D_inc4 D_inc5 D_incrf [aweight = weight] if pid7 > 4 & pid7 < 8, robust
outreg2 using Tables/TableSA08_PredictingVotingExclusionaryPartisanship, /*
  */excel bracket aster(se) dec(3) label addstat(Controls, 0) /*
  */ctitle("Republicans") append

*** logistic regression versions of models from Table 5
glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label /*
  */title("Table SA9: Logistic Regression, Correlates of Primary Election Participation Among General Election Voters") /*
  */replace
glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i knowledge D_* [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append

glm voted_primaries_10or12 prim_soc_norms_scale prim_exclusion_scale /*
  */[aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append
glm voted_primaries_10or12 prim_soc_norms_scale prim_exclusion_scale /*
  */knowledge D_* [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append

glm voted_primaries_10or12 prim_soc_norms_scale knowledge Z_* D_pidstr* /*
  */[aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append
glm voted_primaries_10or12 prim_soc_norms_scale knowledge Z_* D_* /*
  */[aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append

glm voted_primaries_10or12 electype_hprim_yhp27e [aweight = weight], /*
  */link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append
glm voted_primaries_10or12 electype_hprim_yhp27e knowledge D_* /*
  */[aweight = weight], link(logit) robust
outreg2 using Tables/TableSA09_LogisticPredictiveVoting1WithControls, excel /*
  */bracket aster(se) dec(3) label append

*** Tables 6 and SA10, correlates of primary voting, additional specifications
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e [aweight = weight], robust
outreg2 using Tables/Table06_PredictingVoting2, excel bracket aster(se) /*
  */dec(3) label addstat(State Fixed Effects?, 0, Controls, 0) /*
  */title("Table 6: Correlates of Primary Election Participation Among General Election Voters, Additional Specifications") /*
  */replace
outreg2 using Tables/TableSA10_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) /*
  */title("Table SA10: Correlates of Primary Election Participation Among General Election Voters, Additional Specifications, with Controls Displayed") /*
  */replace
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* [aweight = weight], robust
outreg2 using Tables/Table06_PredictingVoting2, excel bracket aster(se) /*
  */dec(3) label drop(D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale /*
  */D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf) /*
  */addstat(State Fixed Effects?, 0, Controls, 1) append
outreg2 using Tables/TableSA10_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) append

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/Table06_PredictingVoting2, excel bracket aster(se) /*
  */dec(3) label drop(D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale /*
  */D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf) /*
  */addstat(State Fixed Effects?, 0, Controls, 1) append
outreg2 using Tables/TableSA10_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* dlog_spend_14 rlog_spend_14 /*
  */miss_cdinfo i.inputstate [aweight = weight], robust
outreg2 using Tables/Table06_PredictingVoting2, excel bracket aster(se) /*
  */dec(3) label drop(D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale /*
  */D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf) /*
  */addstat(State Fixed Effects?, 1, Controls, 1) append
outreg2 using Tables/TableSA10_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule fracindexd14 fracindexr14 /*
  */miss_cdinfo [aweight = weight], robust
outreg2 using Tables/Table06_PredictingVoting2, excel bracket aster(se) /*
  */dec(3) label drop(D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale /*
  */D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf) /*
  */addstat(State Fixed Effects?, 0, Controls, 1) append
outreg2 using Tables/TableSA10_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) append

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* fracindexd14 fracindexr14 miss_cdinfo /*
  */i.inputstate [aweight = weight], robust
outreg2 using Tables/Table06_PredictingVoting2, excel bracket aster(se) /*
  */dec(3) label drop(D_educ2 D_educ3 D_educ4 D_age D_age2 D_isfemale /*
  */D_racenotwhite D_polint2 D_polint3 D_inc1 D_inc2 D_inc4 D_inc5 D_incrf) /*
  */addstat(State Fixed Effects?, 1, Controls, 1) append
outreg2 using Tables/TableSA10_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

*** Table 6 analysis with a common sample
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule fracindexd14 fracindexr14 /*
  */miss_cdinfo [aweight = weight], robust
gen tab6fractionalizationsample = e(sample)
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
gen tab6spendingsample = e(sample)

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e [aweight = weight] if tab6spendingsample == 1, robust
outreg2 using Tables/TableSA21_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) /*
  */title("Table SA21: Correlates of Primary Election Participation Among General Election Voters, Additional Specifications, Complete Control, Campaign Spending, and Fractionalization Samples") /*
  */replace
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* [aweight = weight] if /*
  */tab6spendingsample == 1, robust
outreg2 using Tables/TableSA21_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) append

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e [aweight = weight] if /*
  */tab6fractionalizationsample == 1, robust
outreg2 using Tables/TableSA21_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* [aweight = weight] if /*
  */tab6fractionalizationsample == 1, robust
outreg2 using Tables/TableSA21_PredictiveVoting2WithControls, excel bracket /*
  */aster(se) dec(3) label addstat(State Fixed Effects?, 0) append

*** logistic regression versions of Table 6
glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA11_LogisticPredictiveVoting2WithControls, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) /*
  */title("Table SA11: Logistic Regression, Correlates of Primary Election Participation Among General Election Voters, Additional Specifications") /*
  */replace
glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA11_LogisticPredictiveVoting2WithControls, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) append

glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA11_LogisticPredictiveVoting2WithControls, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* dlog_spend_14 rlog_spend_14 /*
  */miss_cdinfo i.inputstate [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA11_LogisticPredictiveVoting2WithControls, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule fracindexd14 fracindexr14 /*
  */miss_cdinfo [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA11_LogisticPredictiveVoting2WithControls, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
glm voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* fracindexd14 fracindexr14 miss_cdinfo /*
  */i.inputstate [aweight = weight], link(logit) robust
outreg2 using Tables/TableSA11_LogisticPredictiveVoting2WithControls, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

*** verifying that column (11) and (12) results are unchanged if we use 2012,
***   not 2014 spending data, as reported in  footnote 15
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_12 /*
  */rlog_spend_12 miss_cdinfo [aweight = weight], robust
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* dlog_spend_12 rlog_spend_12 /*
  */miss_cdinfo i.inputstate [aweight = weight], robust

*** Table 6 specifications with primary openness measure, using alternative
***   measure for openness
*indicator for states with open primary
gen open = primaryrule == 0
* differentiate top-two primaries from other open primaries (CA, LA, WA)
replace open = 0 if statefips == 6 | statefips == 22 | statefips == 53
gen toptwo = 0
replace toptwo = 1 if statefips == 6 | statefips == 22 | statefips == 53
*indicator for states with closed primaries
gen closed = primaryrule == 1
*indicator for states with any hybrid open/closed system
gen semiopen = primaryrule == .25 | primaryrule == .5 | primaryrule == .75

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* open semi toptwo dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA12_PredictiveVoting2WithControlsAltOpenness, /*
  */excel bracket aster(se) dec(3) label /*
  */title("Table SA12: Correlates of Primary Election Participation Among General Election Voters, Additional Specifications, with Controls Displayed, Alternative Openness Measure") /*
  */replace
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* open semi toptwo fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA12_PredictiveVoting2WithControlsAltOpenness, /*
  */excel bracket aster(se) dec(3) label append

*** Table SA13, explaining calculus of voting, norms, and deference attitudes
***   using spending variables
regress electype_hprim_yhp27b knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA13_IVsExplainedByContextVars1, excel bracket /*
  */aster(se) dec(3) label ctitle("My vote matters a great deal") /*
  */title("Table SA13: Relationship Between Calculus of Voting, Norms, and Deference Attitudes and Campaign Spending Variables") /*
  */replace
regress electype_hprim_yhp27c knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA13_IVsExplainedByContextVars1, excel bracket /*
  */aster(se) dec(3) label /*
  */ctitle("Outcome of election has big effect on my life") append
regress electype_hprim_yhp27i knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA13_IVsExplainedByContextVars1, excel bracket /*
  */aster(se) dec(3) label /*
  */ctitle("Easy to figure out which candidate to vote for") append
regress prim_soc_norms_scale knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA13_IVsExplainedByContextVars1, excel bracket /*
  */aster(se) dec(3) label ctitle("Social Norms Scale") append
regress prim_exclusion_scale knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA13_IVsExplainedByContextVars1, excel bracket /*
  */aster(se) dec(3) label ctitle("Exclusionary Norms Scale") append
regress electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA13_IVsExplainedByContextVars1, excel bracket /*
  */aster(se) dec(3) label /*
  */ctitle("Others will do a good job of picking candidate") append

*** Table SA14, explaining calculus of voting, norms, and deference attitudes
***   using fractionalization index
regress electype_hprim_yhp27b knowledge D_* primaryrule fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA14_IVsExplainedByContextVars2, excel bracket /*
  */aster(se) dec(3) label ctitle("My vote matters a great deal") /*
  */title("Table SA14: Relationship Between Calculus of Voting, Norms, and Deference Attitudes and Fractionalization Variables") /*
  */replace
regress electype_hprim_yhp27c knowledge D_* primaryrule fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA14_IVsExplainedByContextVars2, excel bracket /*
  */aster(se) dec(3) label /*
  */ctitle("Outcome of election has big effect on my life") append
regress electype_hprim_yhp27i knowledge D_* primaryrule fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA14_IVsExplainedByContextVars2, excel bracket /*
  */aster(se) dec(3) label /*
  */ctitle("Easy to figure out which candidate to vote for") append
regress prim_soc_norms_scale knowledge D_* primaryrule fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA14_IVsExplainedByContextVars2, excel bracket /*
  */aster(se) dec(3) label ctitle("Social Norms Scale") append
regress prim_exclusion_scale knowledge D_* primaryrule fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA14_IVsExplainedByContextVars2, excel bracket /*
  */aster(se) dec(3) label ctitle("Exclusionary Norms Scale") append
regress electype_hprim_yhp27e knowledge D_* primaryrule fracindexd14 /*
  */fracindexr14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA14_IVsExplainedByContextVars2, excel bracket /*
  */aster(se) dec(3) label /*
  */ctitle("Others will do a good job of picking candidate") append

*** Table SA15 correlates of 2012 primary election participation among general
***   election voters

** DV for 2012 primary voters only
gen voted_primaries_12 = 0
replace voted_primaries_12 = 1 if primary_2012 == 1

regress voted_primaries_12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_12 /*
  */rlog_spend_12 miss_cdinfo i.inputstate [aweight = weight], robust
outreg2 using Tables/TableSA15_PredictingVoting2_2012PrimaryVotersOnly, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) /*
  */title("Table SA15: Correlates of 2012 Primary Election Participation Among General Election Voters") /*
  */replace
regress voted_primaries_12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule fracindexd12 fracindexr12 /*
  */miss_cdinfo i.inputstate [aweight = weight], robust
outreg2 using Tables/TableSA15_PredictingVoting2_2012PrimaryVotersOnly, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

** flag states in 2012 with congressional and presidential primary on the same
**   day; taken from 2014
gen prim_2012_sameday = 0
replace prim_2012_sameday = 1 if inputstate == 01 | inputstate == 2 | /*
  */inputstate == 6 | inputstate == 17 | inputstate == 18 | /*
  */inputstate == 21 | inputstate == 24 | inputstate == 28 | /*
  */inputstate == 30 | inputstate == 31 | inputstate == 34 | /*
  */inputstate == 35 | inputstate == 37 | inputstate == 39 | /*
  */inputstate == 41 | inputstate == 42 | inputstate == 46 | /*
  */inputstate == 48 | inputstate == 49 | inputstate == 54

regress voted_primaries_12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_12 /*
  */rlog_spend_12 miss_cdinfo prim_2012_sameday i.inputstate /*
  */[aweight = weight], robust
outreg2 using Tables/TableSA15_PredictingVoting2_2012PrimaryVotersOnly, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append
regress voted_primaries_12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule fracindexd12 fracindexr12 /*
  */miss_cdinfo prim_2012_sameday i.inputstate [aweight = weight], robust
outreg2 using Tables/TableSA15_PredictingVoting2_2012PrimaryVotersOnly, excel /*
  */bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

*** Table SA17, factor analysis of social and exclusionary norms scales
set more off
factor primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c primnorms_yhp30e /*
  */socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f /*
  */[aweight = weight], pcf
matrix eigen = e(Ev)
matrix loadings = e(L)
forvalues i = 1/6 {
  local eigendiff`i' = round(eigen[1,`i'] - eigen[1,`i' + 1], 0.001)
}
local eigendiff7 = ""
local eigentotal = eigen[1,1] + eigen[1,2] + eigen[1,3] + eigen[1,4] + /*
  */eigen[1,5] + eigen[1,6] + eigen[1,7]
forvalues i = 1/7 {
  local eigenprop`i' = round(eigen[1,`i'] / `eigentotal', .001)
}
local eigencumprop1 = round(eigen[1,1] / `eigentotal', .001)
forvalues i = 2/7 {
  local prev = `i' - 1
  local eigencumprop`i' = round(`eigenprop`i'' + `eigencumprop`prev'', .001)
}
putexcel set Tables/TableSA17_SocialExclusionaryNormsFactorAnalysis, /*
  */replace
putexcel A1 = ("Table SA17: Principal Components Factor Analysis of Social and Exclusionary Norms")
putexcel A2 = ("Principle Components Analysis (Unrotated)")
putexcel B3 = ("Eigenvalue") C3 = ("Difference") /*
  */D3 = ("Eigenvalue Proportion") E3 = ("Cumulative Eigenvalue Proportion")
forvalues i = 1/7 {
  local row = `i' + 3
  putexcel A`row' = ("Factor `i'") B`row' = (round(eigen[1,`i'], .001)) /*
    */C`row' = ("`eigendiff`i''") D`row' = ("`eigenprop`i''") /*
    */E`row' = ("`eigencumprop`i''")
}
putexcel A11 = ("Factor Loadings")
putexcel A12 = ("Variable") B12 = ("Factor 1 Loading") /*
  */C12 = ("Factor 2 Loading") D12 = ("Unique Variance")
forvalues i = 1/2 {
  forvalues j = 1/7 {
    local loadings`j'`i' = round(loadings[`j',`i'], .001)
  }
}
local scalevars = "primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c primnorms_yhp30e socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f"
foreach var of varlist primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f {
  local varlab : variable label `var'
}
forvalues i = 1/7 {
  local row = `i' + 12
  local thisvar : word `i' of `scalevars'
  local varlab : variable label `thisvar'
  display "`thisvar'"
  display "`varlab'"
  putexcel A`row' = ("`varlab'") B`row' = ("`loadings`i'1'") /*
    */C`row' = ("`loadings`i'2'")
}

rotate, factor(2)
scree, yline(1) scheme(s1mono) title("")
graph export Figures/FigureSA01-ScreePlotExclusionarySocial.pdf, replace
graph close _all
predict prim_soc_norms_scale_pcf prim_exclusion_scale_pcf
label var prim_soc_norms_scale_pcf "Social Norms Scale (PCF)"
label var prim_exclusion_scale_pcf "Exclusionary Norms Scale (PCF)"

matrix r_eigen = e(r_Ev)
matrix r_loadings = e(r_L)
matrix r_uniquevariance = e(Psi)
local r_eigendiff1 = round(r_eigen[1,1] - r_eigen[1,2], 0.001)
local r_eigendiff2 = ""

forvalues i = 1/2 {
  local r_eigenprop`i' = round(r_eigen[1,`i'] / `eigentotal', .001)
}
local r_eigencumprop1 = round(r_eigen[1,1] / `eigentotal', .001)
local r_eigencumprop2 = round(`r_eigenprop2' + `r_eigencumprop1', .001)

putexcel A20 = ("Principal Components Analysis (Varimax Rotation)")
putexcel B21 = ("Variance") C21 = ("Difference") /*
  */D21 = ("Variance Proportion") E21 = ("Cumulative Variance Proportion")
forvalues i = 1/2 {
  local row = `i' + 21
  putexcel A`row' = ("Factor `i'") B`row' = (round(r_eigen[1,`i'], .001)) /*
    */C`row' = ("`r_eigendiff`i''") D`row' = ("`r_eigenprop`i''") /*
    */E`row' = ("`r_eigencumprop`i''")
}
local r_chi2 = round(`e(chi2_i)', .001)
local r_stars = cond(`e(p_i)' < .01, "***", cond(`e(p_i)' < .05, "**", /*
  */cond(`e(p_i)' < .1, "*", "")))
putexcel A24 = ("Rotated Factor Loadings")
putexcel A25 = ("Variable") B25 = ("Factor 1 Loading") /*
  */C25 = ("Factor 2 Loading") D25 = ("Unique Variance")

forvalues i = 1/2 {
  forvalues j = 1/7 {
    local r_loadings`j'`i' = round(r_loadings[`j',`i'], .001)
  }
}
forvalues i = 1/7 {
  local r_uniquevariance`i' = round(r_uniquevariance[1,`i'], .001)
}
local scalevars = "primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c primnorms_yhp30e socnorms_hprim_yhp33a socnorms_hprim_yhp33b socnorms_hprim_yhp33f"
foreach var of varlist primnorms_yhp30a primnorms_yhp30b primnorms_yhp30c /*
  */primnorms_yhp30e socnorms_hprim_yhp33a socnorms_hprim_yhp33b /*
  */socnorms_hprim_yhp33f {
  local varlab : variable label `var'
}
forvalues i = 1/7 {
  local row = `i' + 25
  local thisvar : word `i' of `scalevars'
  local varlab : variable label `thisvar'
  putexcel A`row' = ("`varlab'") B`row' = ("`r_loadings`i'1'") /*
    */C`row' = ("`r_loadings`i'2'") D`row' = ("`r_uniquevariance`i''")
}
putexcel A33 = ("Likelihood Ratio Test of Factor Independence vs. Saturated Model: chi-squared = `r_chi2'`r_stars'")

*** alternative specifications excluding DK responses from social norms scale
foreach var of varlist yhp33* {
  recode `var' (1 = 1) (2 = .667) (3 = .333) (4 = 0) (* = .), /*
    */gen(socnorms_hprim_`var'_alt)
}
label var socnorms_hprim_yhp33a_alt /*
  */"House Prim. - If Don't Vote, Family/Friends Disappointed"
label var socnorms_hprim_yhp33b_alt /*
  */"House Prim. - If Don't Stay Informed, Family/Friends Disappointed"
label var socnorms_hprim_yhp33c_alt /*
  */"House Prim. - Most of My Family/Friends Vote"
label var socnorms_hprim_yhp33d_alt /*
  */"House Prim. - Most of My Family/Friends Stay Informed"
label var socnorms_hprim_yhp33e_alt /*
  */"House Prim. - Family/Friends Will Find Out if I Don't Vote"
label var socnorms_hprim_yhp33f_alt "House Prim. - I Feel Bad if I Cannot Vote"
label var socnorms_hprim_yhp33g_alt /*
  */"House Prim. - It is Important to Turn Out and Vote"

alpha socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt 
pwcorr socnorms_hprim_yhp33a_alt socnorms_hprim_yhp33b_alt /*
  */socnorms_hprim_yhp33f_alt, sig
gen prim_soc_norms_scale_alt = (socnorms_hprim_yhp33a_alt + /*
  */socnorms_hprim_yhp33b_alt + socnorms_hprim_yhp33f_alt) / 3
label var prim_soc_norms_scale_alt "Social Pressure/Norms Scale (0 - 1)"

*** fix constant sample for Table SA19
qui regress voted_primaries_10or12 electype_hprim_yhp27b p_times_b /*
  */electype_hprim_yhp27c electype_hprim_yhp27i prim_soc_norms_scale_alt /*
  */prim_exclusion_scale electype_hprim_yhp27e D_* [aweight = weight], robust
keep if e(sample)

sum voted_primaries_10or12 electype_hprim_yhp27b p_times_b /*
  */electype_hprim_yhp27c electype_hprim_yhp27i prim_soc_norms_scale_alt /*
  */prim_exclusion_scale electype_hprim_yhp27e D_* [aweight = weight]

regress voted_primaries_10or12 prim_soc_norms_scale_alt prim_exclusion_scale /*
  */[aweight = weight], robust
outreg2 using Tables/TableSA18_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label /*
  */title("Table SA18: Correlates of Primary Election Participation Among General Election Voters, Dropping Don't Know Responses for Social Norms Scale") /*
  */replace
regress voted_primaries_10or12 prim_soc_norms_scale_alt prim_exclusion_scale /*
  */knowledge D_* [aweight = weight], robust
outreg2 using Tables/TableSA18_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label append
regress voted_primaries_10or12 prim_soc_norms_scale_alt Z_* D_pidstr* /*
  */[aweight = weight], robust
outreg2 using Tables/TableSA18_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label append
regress voted_primaries_10or12 prim_soc_norms_scale_alt knowledge Z_* D_* /*
  */[aweight = weight], robust
outreg2 using Tables/TableSA18_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label append

regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale_alt prim_exclusion_scale /*
  */electype_hprim_yhp27e [aweight = weight], robust
outreg2 using Tables/TableSA19_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) /*
  */title("Table SA19: Correlates of Primary Election Participation Among General Election Voters, Additional Specifications, Dropping Don't Know Responses for Social Norms Scale") /*
  */replace
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale_alt prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* [aweight = weight], robust
outreg2 using Tables/TableSA19_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale_alt prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule dlog_spend_14 /*
  */rlog_spend_14 miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA19_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale_alt prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* dlog_spend_14 rlog_spend_14 /*
  */miss_cdinfo i.inputstate [aweight = weight], robust
outreg2 using Tables/TableSA19_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale_alt prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* primaryrule fracindexd14 fracindexr14 /*
  */miss_cdinfo [aweight = weight], robust
outreg2 using Tables/TableSA19_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label addstat(State Fixed Effects?, 0) append
regress voted_primaries_10or12 electype_hprim_yhp27b electype_hprim_yhp27c /*
  */electype_hprim_yhp27i prim_soc_norms_scale_alt prim_exclusion_scale /*
  */electype_hprim_yhp27e knowledge D_* fracindexd14 fracindexr14 miss_cdinfo /*
  */i.inputstate [aweight = weight], robust
outreg2 using Tables/TableSA19_PredictiveVoting1WithControlsExcludingDK, /*
  */excel bracket aster(se) dec(3) label addstat(State Fixed Effects?, 1) append

restore

clear

log close
